Name:           scapy
Version:        2.5.0
Release:        6.20240427163311808499.pr4365.326.g6ea145cf%{?dist}
Summary:        Interactive packet manipulation tool and network scanner

%global         gituser         secdev
%global         gitname         scapy
%global         commit          95ba5b8504152a1f820bbe679ccf03668cb5118f
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

License:        GPL-2.0-only
URL:            https://scapy.net/
#was            http://www.secdev.org/projects/scapy/
VCS:            https://github.com/secdev/scapy
#               https://github.com/secdev/scapy/releases
#               https://bitbucket.org/secdev/scapy/pull-request/80
#               https://scapy.readthedocs.io/en/latest/introduction.html
Source0:        scapy-2.5.0.tar.gz

%global         common_desc %{expand:
Scapy is a powerful interactive packet manipulation program built on top
of the Python interpreter. It can be used to forge or decode packets of
a wide number of protocols, send them over the wire, capture them, match
requests and replies, and much more.}


# By default build with python3 subpackage
%bcond_without     python3

# Build also the python2 package on releases up to fc31 and rhel8
%if (0%{?fedora} && 0%{?fedora} <= 31 ) || ( 0%{?rhel} && 0%{?rhel} <= 8 )
%bcond_without     python2
%else
%bcond_with        python2
%endif

# By default build the documentation only on Fedora due to cc-by-nc-sa license
%if 0%{?fedora}
%bcond_without     doc
%else
%bcond_with        doc
%endif




BuildArch:      noarch
BuildRequires: samba-client
BuildRequires: samba
BuildRequires: python3-zstandard
BuildRequires: python3-tkinter
BuildRequires: python3-cryptography
BuildRequires: python3-coverage
BuildRequires: python3-can
BuildRequires: python3-brotli
BuildRequires: python3-ipython
BuildRequires: python3-mock
BuildRequires: python3-tox-current-env
BuildRequires: wireshark
BuildRequires: tcpdump
BuildRequires: openssl
BuildRequires: libpcap
BuildRequires: can-utils

BuildRequires:  make
BuildRequires:  sed

%if %{with python2}
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
%if %{with doc}
BuildRequires:  python2-tox
%endif
%endif

%if %{with python3}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
%if %{with doc}
BuildRequires:  python%{python3_pkgversion}-tox
%endif
%endif

# Recommends only supported on fedora and rhel8+
%if (0%{?fedora}) || ( 0%{?rhel} && 0%{?rhel} >= 8 )
Recommends:     tcpdump
# Using database of manufactures /usr/share/wireshark/manuf
Recommends:     wireshark-cli
%endif

%description %{common_desc}

%if %{with python2}
%package -n python2-%{name}
Summary:        Interactive packet manipulation tool and network scanner

%{?python_provide:%python_provide python2-%{name}}

%if (0%{?fedora}) || ( 0%{?rhel} && 0%{?rhel} >= 8 ) 
Recommends:     python2-pyx
Recommends:     python2-matplotlib
Recommends:     ipython2
%endif

%description -n python2-%{name}
%{common_desc}

%endif


%if %{with python3}
%package -n python%{python3_pkgversion}-%{name}
Summary:        Interactive packet manipulation tool and network scanner

%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}
Provides:       %{name} = %{version}-%{release}

%if (0%{?fedora}) || ( 0%{?rhel} && 0%{?rhel} >= 8 ) 
Recommends:     PyX
Recommends:     python%{python3_pkgversion}-matplotlib
Recommends:     ipython3
%endif

%description -n python%{python3_pkgversion}-%{name}
%{common_desc}
%endif

%if %{with doc}
%package doc
Summary:        Interactive packet manipulation tool and network scanner
License:        CC-BY-NC-SA-2.5

BuildRequires:  python%{python3_pkgversion}-sphinx
BuildRequires:  python%{python3_pkgversion}-sphinx_rtd_theme

%description doc
%{common_desc}
%endif



%prep
%autosetup -p 1 -n scapy-2.5.0

# Remove shebang
# https://github.com/secdev/scapy/pull/2332
SHEBANGS=$(find ./scapy -name '*.py' -print | xargs grep -l -e '^#!.*env python')
for FILE in $SHEBANGS ; do
    sed -i.orig -e 1d "${FILE}"
    touch -r "${FILE}.orig" "${FILE}"
    rm "${FILE}.orig"
done



%build
%if %{with python2}
%py2_build
%endif

%if %{with python3}
%py3_build
%endif

%if %{with doc}
make -C doc/scapy html BUILDDIR=_build_doc SPHINXBUILD=sphinx-build-%python3_version

rm -f doc/scapy/_build_doc/html/.buildinfo
rm -f doc/scapy/_build_doc/html/_static/_dummy
%endif



%install
install -dp -m0755 %{buildroot}%{_mandir}/man1
install -Dp -m0644 doc/scapy.1* %{buildroot}%{_mandir}/man1/

%if %{with python2}
%py2_install
rm -f %{buildroot}%{python2_sitelib}/*egg-info/requires.txt


# Rename the executables
mv -f %{buildroot}%{_bindir}/scapy   %{buildroot}%{_bindir}/scapy2

%if ! %{with python3}
# Link the default to the py2 version of executables if py3 not built
ln -s %{_bindir}/scapy2   %{buildroot}%{_bindir}/scapy
%endif
%endif

%if %{with python3}
%py3_install
rm -f %{buildroot}%{python3_sitelib}/*egg-info/requires.txt

# Rename the executables
mv -f %{buildroot}%{_bindir}/scapy   %{buildroot}%{_bindir}/scapy3

# Link the default to the python3 version of executables
ln -s %{_bindir}/scapy3   %{buildroot}%{_bindir}/scapy
%endif



# check
%check
./test/run_tests -c test/configs/linux.utsc -K netaccess -K scanner -K manufdb
# TODO: Need to fix/remove slow/failed test
# cd test/
# ./run_tests_py2 || true
# ./run_tests_py3 || true



%if %{with python2}
%files -n python2-%{name}
%license LICENSE
%if ! %{with python3}
%doc %{_mandir}/man1/scapy.1*
%{_bindir}/scapy
%endif
%{_bindir}/scapy2
%{python2_sitelib}/scapy/
%{python2_sitelib}/scapy-*.egg-info
%exclude %{python2_sitelib}/test/
%endif



%if %{with python3}
%files -n python%{python3_pkgversion}-%{name}
%license LICENSE
%doc %{_mandir}/man1/scapy.1*
%{_bindir}/scapy
%{_bindir}/scapy3
%{python3_sitelib}/scapy/
%{python3_sitelib}/scapy-*.egg-info
%exclude %{python3_sitelib}/test/
%endif


%if %{with doc}
%files doc
%doc doc/scapy/_build_doc/html
%endif


%changelog
* Sat Apr 27 2024 Packit <hello@packit.dev> - 2.5.0-6.20240427163311808499.pr4365.326.g6ea145cf
- SMB2: support write & file/folder creation (gpotter2)
- Add `stop_filter` to SndRcvHandler (#4361) (Brett Sullivan)
- Reworked hashret in uds.py after #4347 (#4364) (Nils Weiss)
- UDS Scanner Update (#4362) (Nils Weiss)
- automotive/uds: special case to allow sending malformed 7f request (#4347) (Ben Gardiner)
- Set manual_trigger in packit (gpotter2)
- CI: run scapy on aarch64, i386, ppc64le, s390x and x86_64 on PRs (#4355) (Evgeny Vereshchagin)
- Fix RTCP parsing with SR or multiple RR (#4349) (Leonard Crestez)
- SMB + Kerberos improvements (#4344) (gpotter2)
- Rewrite ICMP extensions (#4332) (gpotter2)
- Unify dicts for Netflow fields (#4335) (gpotter2)
- Fix ICMPv6 hashret()/answers() with IPv6ExtHdrDestOpt (#4333) (gpotter2)
- Fix #3750: Use MultipleTypeField in SomeIP  (#4317) (Nils Weiss)
- TLS ATMT client: support custom SSLv2ClientHello (#4339) (edhinard)
- scapy.1 typo (gpotter2)
- Update scapy.1: license & content (#4337) (gpotter2)
- Fix display() usage instead of show() (gpotter2)
- Bluetooth: Fix HCI_Cmd_Read_Remote_Extended_Features binding (#4302) (Antonio Vazquez)
- Bluetooth: fix HCI_Cmd_Write_Local_Name command (#4303) (Antonio Vazquez)
- Fix typo in kerberos.py (gpotter2)
- Cosmetic changes to Kerberos and SMB (#4326) (gpotter2)
- Add LDAP client (#4323) (gpotter2)
- Windows SSPs: various improvements (#4314) (gpotter2)
- Fix (SSL)StreamSocket handling of underflowed data. (#4315) (gpotter2)
- Auto-Argparse for smb{client,server} (#4313) (gpotter2)
- Fix neighsol timeout not actually used (#4310) (Mattia Dal Ben)
- SMB: support BUFFER_OVERFLOW and NTLM without TimeStamp (#4309) (gpotter2)
- HTTP 1.0: support HEAD in reconstruction (#4307) (gpotter2)
- ASN.1: minor cleanup + LDAP/KRB bug fixes (#4306) (gpotter2)
- Fix imports of cryptography for 43.0+ (gpotter2)
- [inet6] make ICMPv6NDOptUnknown a bit more fuzzable (#4305) (Evgeny Vereshchagin)
- Basic [MS-BRWS] support (#4300) (gpotter2)
- TLS: add support for post-handshake auth (#4295) (gpotter2)
- Fix arping() without routes configured (#4293) (gpotter2)
- Support range format in IP(v6) fields (#4284) (gpotter2)
- Fix DNSStrField multiple values (#4256) (gpotter2)
- DNS: add HINFO resource record (#4299) (Evgeny Vereshchagin)
- Fix HCI_Event_Inquiry_Result parsing (#4298) (Antonio Vazquez)
- Support keywords in CLIUtil + improve smbclient (gpotter2)
- Add json() (#4283) (gpotter2)
- Support all versions of NETLOGON_SAM_LOGON* (gpotter2)
- Support IPv6 in contrib/pim.py (#4282) (fusemich)
- Add tons of heuristics to parse old NTLM (#4292) (gpotter2)
- Add RTSP and minor fixes (#4279) (gpotter2)
- Added support for Counter64 in asn1 and ber (for snmp v2c) (#4272) (Mark Howerton)
- Support RC2 in cryptography 43.0+ (#4285) (Paul Kehrer)
- Update codecov-action to v4 (#4291) (gpotter2)
- Hack support for terrible RSA key-lengths in cryptography 43.0 (#4290) (gpotter2)
- Fix StreamSocket on windows (gpotter2)
- Faster TLS client/server tests (#4288) (gpotter2)
- Add TLS_RSA_EXPORT_WITH_RC2_CBC_40_MD5 test (#4286) (gpotter2)
- DNS: support DNAME RRs in DNSRRs (#4249) (Evgeny Vereshchagin)
- Minor windows bug fixes (#4255) (gpotter2)
- Fix OCSP_RevokedInfo (gpotter2)
- Auto clear DNS cache on set (gpotter2)
- BT: cleanup libc loading (#4278) (gpotter2)
- Clarify that the DOC is under CC BY-NC-SA 2.5 (#4254) (gpotter2)
- Automatically check SPDX identifiers (#4268) (Guillaume Valadon)
- Update check_spdx.sh to return 1 on failure (#4277) (gpotter2)
- Fix MQTT SubAck retcodes (#4257) (gpotter2)
- Fix in4_pseudoheader being destructive (#4259) (gpotter2)
- Catch shutting down ImportError (#4267) (gpotter2)
- Fix Geneve dissection (#3917) (Pavel)
- Fix GTP payload length computation (#3822) (vk-coder)
- Bluetooth: Add more HCI event packets (#4165) (Antonio Vazquez)
- Fix show() on non-UTC Kerberos (gpotter2)
- Bluetooth: refactor Bluetooth Monitor packets (#4091) (Antonio Vazquez)
- GRE-in-UDP uses port 4754 (see RFC 8086) (#4057) (Alex Forencich)
- RTPS: Pack count field of ACKNACK submessage correctly (#3915) (Seulbae Kim)
- Add OAM layer (#3770) (Matsievskiy S.V)
- CDP: add CDPMsgPowerRequest and CDPMsgPowerAvailable (#3805) (CQ)
- RTPS: Handle SequenceNumber_t correctly (Seulbae Kim)
- Extended Sequence Numbers support in ESP (Van-Phu Ha)
- Add RPL Hop-by-Hop option (RFC 6553) (Thibaut Vandervelden)
- Rename modbus 'payload' field (#4243) (gpotter2)
- Ignore bad UTF8 in NSS files (#4261) (gpotter2)
- Correctly raise on bad filter (#4241) (gpotter2)
- Make tkinter optional in ticketer (#4258) (gpotter2)
- UTscapy: treat SyntaxWarning as errors (#4260) (gpotter2)
- Make sure all core files have an SPDX (#4263) (gpotter2)
- Scapy 2.6.0+ supports Python 3.7+ (gpotter2)
- Add BGP LARGE_COMMUNITY Path Attribute (#3535) (Qingtian-Zou)
- Add TCPROS layer to contrib (#3462) (Víctor Mayoral Vilches)
- avoid repeated update of some fields (fouzhe)
- Merge tests and tweaks with existing EAPOL_KEY class (TheMadProphet)
- Bluetooth: Add more L2CAP commands (haramel)
- Fixed ESP padding in decryption (Paweł Pachocki)
- Fix SRP not detecting valid SAE auth responses (#3951) (ProofNetPopperl)
- Correct misleading documentation (rdhammond15)
- Fix Loopback Layer: support DLT_LOOP on all plateforms (Guillaume Valadon)
- Make m2i match i2m in NBytesField (Evgeny Vereshchagin)
- Allow to disable auto-loading of routes (gpotter2)
- Fix coverage tests on MacOS (gpotter2)
- Fixes an issue, where TLSClientHello extensions were overwritten (Loris1123)
- The Windows Update (#4214) (gpotter2)
- Update github actions (gpotter2)
- GTPv2: Fix typo in ChargingCharacteristics (#4203) (Mark Shiryaev)
- Fix MultipleTypeField on ASN.1 packets and OSCP (#4222) (#4223) (gpotter2)
- packet: don't always skip empty values in .command() (#4238) (Evgeny Vereshchagin)
- [inet6] recognize unknown router advertisement options (#4233) (Evgeny Vereshchagin)
- Support cryptography>=42.0 (and restore TLS tests) (gpotter2)
- Only create default config file in interactive mode (#4218) (gpotter2)
- DNS: add the SVCB/HTTPS resource records (#4217) (Evgeny Vereshchagin)
- DNS: add the DNS COOKIE EDNS(0) option (Evgeny Vereshchagin)
- DNS: update DNSSEC algorithm numbers (Evgeny Vereshchagin)
- Fix typo (#4210) (Teppei.F)
- Use aux data in NativeCANSocket to determine timestamp of packet (#4208) (Nils Weiss)
- DNS: add the DAU, DHU and N3U EDNS(0) options (Evgeny Vereshchagin)
- DNS: use the right type in MX RRs (Evgeny Vereshchagin)
- update type of `default` param in LEFieldLenField (Gnought)
- hexdiff: 2 algorithms, doc (gpotter2)
- DNS: tweak extract_padding in EDNS(0) options (Evgeny Vereshchagin)
- Type hint arch/bpf (#3825) (gpotter2)
- Add additional errno handling to ISOTPNativeSocket to prevent accidental close (#4193) (Nils Weiss)
- Improve parsing of UDS DTC Snapshots and ExtendedData (#4149) (Nils Weiss)
- readthedocs: fix renamed extra requirement (gpotter2)
- IPython banner: restore \n (gpotter2)
- Fix broken documentation link (Omer Rosenbaum)
- Fixed typo in routing.rst (Gal Fudim)
- enable enumerator unit tests for linux (Nils Weiss)
- L2ListenTcpdump: Support quiet mode (#4172) (Orgad Shaneh)
- Fix documentation (#4181) (TAKAHiRO TOMiNAGA)
- Add SSHv2 (RFC 4250, 4251, 4252, 4253 and 4254) (gpotter2)
- Cache `get_if_hwaddr` for SourceMACField (#4187) (gpotter2)
- Improve main.interact() banner + support exts (gpotter2)
- Updated DDS RTPS Vendor IDs using DDS-Foundation spec (#4159) (Cooper de Nicola)
- Fix padwith in PadField (gpotter2)
- Fix geneve tests (gpotter2)
- Disable enumerator tests (gpotter2)
- DNS: make it possible to include empty strings in TXT RDATA (Evgeny Vereshchagin)
- Fix and add test for GENEVE.optionlen (hujingfei)
- Modify packet definition of UDS_IOCBI packet to allow customization (#4161) (Nils Weiss)
- packet: Remove trailing whitespace (Jose Luis Duran)
- Fix exception on failed _BluetoothLibcSockets (Antonio Vázquez Blanco)
- README: new badge URL (gpotter2)
- Bump mypy to 1.7.0 and tox (gpotter2)
- 802.11: support badly implemented Country Information padding (#4133) (Gilad Beeri)
- Support 3.11 and 3.12 (gpotter2)
- Update build versions (gpotter2)
- ReadTheDocs: fix displayed Scapy version (gpotter2)
- tacacs: support unencrypted packets (gidder)
- Intro doc edits (#4162) (ntheule)
- DHCPv4: add the rapid commit option (#4166) (Evgeny Vereshchagin)
- Pass the fd to underlying NativeCANSocket (#4158) (devrim-ayyildiz)
- Improve answering machines, dns_resolve, renames (gpotter2)
- More consistent sendpfast API (breaking) (#4157) (gpotter2)
- Fix enum in UDS BMW definitions (#4150) (Nils Weiss)
- Improve exception handling in PeriodicSender Thread (#4152) (Nils Weiss)
- Support stupid OSes (gpotter2)
- Minor cleanup and add utility function for Automotive Scanner (Nils Weiss)
- Fix UDP header in IPSec NAT-Traversal. (#4125) (Paweł Pachocki)
- Added logic to compute ICRC for RoCEv2 over IPv6 (#4154) (leonidokner)
- Add parsing of ExtendedDataRecord to UDS_DTCs (#4117) (Nils Weiss)
- Add more BMW software version definitions (#4143) (Nils Weiss)
- Fix L2 dst address computation (very intrusive) (#4145) (gpotter2)
- Add BitLenField (gpotter2)
- DNS: add Extended DNS Error EDNS0 Option (Evgeny Vereshchagin)
- bluetooth: BluetoothMonitorSocket fix (Antonio V??zquez)
- [DHCPv6] add the NTP Server Option (#4113) (Evgeny Vereshchagin)
- Fix LatexTheme to escape "#" (#4138) (gpotter2)
- Fix tests (#4140) (gpotter2)
- Fix codespell (#4137) (Nils Weiss)
- Resolve Issue_4006 (Justin Breed)
- fix(http2): HPackHdrTable().parse_txt_hdrs() accepts str & bytes (#4131) (Pierre)
- SSLv2: s/debug_dissect/debug_dissector/ (#4129) (Evgeny Vereshchagin)
- Fix NTP poll and precision data types (Paul Gear)
- Fix doipsocket6 (#4076) (superuserx)
- Cleanup IP fragmentation, TCP session and TLS sessions (#4082) (gpotter2)
- Fix Automaton.graph() with indirection (gpotter2)
- Fix readthedocs: update doc dependencies (gpotter2)
- UDS: more precise parsing of DTCs (#4094) (Nils Weiss)
- Added support for CanFD in the ISOTPSoftSocket (#4048) (Nils Weiss)
- Let Scapy load on unsupported platforms (#4111) (gpotter2)
- Add wireshark extcap support (#4101) (gpotter2)
- [DHCPv4] add the IPv6-Only Preferred Option (#4108) (Evgeny Vereshchagin)
- Do not compress 1 octet DNS strings (#4110) (gpotter2)
- Adding a few more Bluetooth HCI Commands (#4103) (Hui Peng)
- PPP: fix default size of protocol field (#4106) (Olivier Matz)
- [INET6] add the PREF64 ND option (#4105) (Evgeny Vereshchagin)
- Use L3RawSocket(6) automatically on lo (#4099) (gpotter2)
- Improve Bluetooth HCI Command packet definition (#4088) (Hui Peng)
- Update uds.py (#4102) (superuserx)
- Add connect_from_ip command (#4098) (gpotter2)
- bluetooth: Add a BT monitor header for pcap parsing (Antonio Vázquez Blanco)
- [LLMNR] recognize the "T"entative bit (#4089) (Evgeny Vereshchagin)
- Update Ethernet/IP contrib and tests (#4083) (Lex)
- Tests: fix AS resolver tests (#4084) (Pierre)
- Scapy terminal improvements (#4073) (gpotter2)
- Add layer HICP (#4075) (Lex)
- add support for exceptions in SNMP varbind responses (Christian Sahlmann)
- Improve dns_resolve (gpotter2)
- Add conf.nameservers + small dns resolver (#4070) (gpotter2)
- Refactor libc sockets and add BluetoothMonitorSocket (#4042) (Antonio Vazquez)
- Don't require newline at end of pcapng comment (#4021) (Nathan Korth)
- NSH: fix layer binding for VXLAN GPE (#4054) (Raslan Darawsheh)
- Fix tiny issue in inet6.uts (gpotter2)
- Improve display of bytes strings (#4062) (Nils Weiss)
- Speedup isotp scan verification function (#4066) (Nils Weiss)
- fix param name in docstring (Tera)
- Turn PIMv2HelloLANPruneDelayValue.t into BitField (Evgeny Vereshchagin)
- Add bufsz parameter to RawPcapWriter constructor (#4067) (Aniket Gargya)
- Update SD class to support Explicit Initial Data Control Flag (haradama)
- Create .git-blame-ignore-revs (#4063) (gpotter2)
- Small typos in usage.rst (#4052) (André David)
- [inet6] add Captive-Portal RA option (#4059) (Evgeny Vereshchagin)
- Fix recv of HSFZ and DoIP (#4053) (Nils Weiss)
- Implement 802.1ah I-Tag for PBB MAC-in-MAC encapsulation (#4009) (Alex Forencich)
- Add LE3BytesEnumField and LEX3BytesEnumField (#4041) (Antonio Vazquez)
- [dhcp6] add Captive-Portal option  (#4050) (Evgeny Vereshchagin)
- Fix issue in Automotive Executor using make_lined_table (#4045) (Nils Weiss)
- Update definitions.py (#4046) (Nils Weiss)
- DNS rewrite + MayEnd (make undersized dissection fail) (#4012) (gpotter2)
- Move LEMACField to fields, refactor it and add tests (#4043) (Antonio Vazquez)
- bluetooth: Remove duplicage XLEShortField implementation (Antonio Vázquez)
- Fix capitalization (#4040) (Nils Weiss)
- bluetooth: Reorder HCI command packets binding to follow opcode (#4037) (Antonio Vazquez)
- Add more HCI command and event packets (#4003) (Gulshan Singh)
- Added myself to the maintainers (Nils Weiss)
- Fix grammar for codespell 2.2.5 (#4032) (gpotter2)
- Fix FixedPointField.i2h to accept None (#3999) (Evgeny Vereshchagin)
- Implement ISOTP packets for CANFD layer (#4022) (Nils Weiss)
- IKEv2: fix length calculation for IKEv2_Notify payloads with SPI (Matthias St. Pierre)
- Import InvalidSignature from the correct location (Alex Gaynor)
- fix depricated argument in python-can (Nils Weiss)
- Add crypto_validator decorator to TLS13_HKDF methods to fix #4005 (Luke Valenta)
- Force the source MAC address in neighsol() (#4020) (Guillaume Valadon)
- Tolerate non-UTF-8 NetBIOS names in NetBIOS answering machines (#4007) (Evgeny Vereshchagin)
- Recognize DNS cookies (#4014) (Evgeny Vereshchagin)
- 802.1q: rename .id field to .dei (Pierre Lalet)
- Look for flag values instead of flag fields (#4004) (Evgeny Vereshchagin)
- Fix debug message from AutomotiveScannerExecutor (Nils Weiss)
- change order of creation of list to allow usage of generators for extended_scan_range (Sebastian Baar)
- Python-can changed it's interface and therefore raised warnings. This PR fixes those warnings (Nils Weiss)
- Use time.monotonic() in sndrcv (gpotter2)
- Tolerate decoding errors in LLMNR queries/responses (Evgeny Vereshchagin)
- No longer include LLTD hostnames in format strings (#3993) (Evgeny Vereshchagin)
- layers/sctp.py: Add support for [I-]Forward-TSN chunks (#3994) (Yuxuan Luo)
- Add AUTOSAR PDUTransport/PDU with initial batch of tests (#3933) (Damian Zaręba)
- Use the typing module (Python 3.7+) (#3976) (gpotter2)
- Make repr(NTPInfoPeer) work (Evgeny Vereshchagin)
- Tests: use conf.ifaces instead of IFACES (gpotter2)
- Add JSON output format for isotpscan (Nils Weiss)
- No longer include DNSSLs in format strings (Evgeny Vereshchagin)
- Make repr(RadioTap) with the hemuou_per_user_known field work (Evgeny Vereshchagin)
- Fix #3947 (Nils Weiss)
- Fix ffdhe creation (gpotter2)
- Pass kwargs to WrpcapSink (gpotter2)
- Fix get_if_list on windows (gpotter2)
- Refactoring of PythonCANSocket (#3928) (Nils Weiss)
- fix parsing when data is unaligned (#3984) (Steven Van Acker)
- Tolerate decoding errors in NetBIOS names (#3971) (Evgeny Vereshchagin)
- No longer use deprecated MACsec fields (#3981) (Evgeny Vereshchagin)
- Support new build methods (#3958) (gpotter2)
- Fix EAPOL_KEY (gpotter2)
- Drop six library (third & last batch) (#3857) (Pierre)
- netflow - add IP_DSCP support (Gabriel Ganne)
- Fix nested ListFields (gpotter2)
- Fix syntax errors (#3960) (Evgeny Vereshchagin)
- Use the daemon attribute instead of setDaemon (Evgeny Vereshchagin)
- Correct several assertions in the NTP test (Evgeny Vereshchagin)
- Add RFC-4543 AES-NULL-GMAC support to IPSec layer (#3935) (Benoît Ganne)
- Show NTP version and mode instead of question marks (#3944) (Evgeny Vereshchagin)
- Remove wrong debug message from Automotive Scanner Executor (#3931) (Nils Weiss)
- Add 802.11 VHT Operation Info (Atakan Isbakan)
- ISAKMP: support nat traversal, various fixes (gpotter2)
- IKEv2: improve dissection of IKEv2 redirect notifications (#3925) (Matthias St. Pierre)
- cleanup: replace bytes(bytearray.fromhex()) with bytes.fromhex() (#3946) (Evgeny Vereshchagin)
- Fix #3897 - Incorrect behavior of NetflowHeaderV9 Count (#3898) (Nicolas Bloyet)
- Several contrib layers cleanups (#3939) (gpotter2)
- Minor tests & coverage fixes (#3924) (gpotter2)
- fix codespell (Nils Weiss)
- layers/sctp.py: Add support for multiple new chunk types (#3846) (Yuxuan Luo)
- Add 802.11 Overlapping BSS Scan Parameters (OBSS) (Atakan Isbakan)
- Add 802.11 Channel Switch Announcement (CSA) (Atakan Isbakan)
- Fix bug #191 (virtualabs)
- Make NBytesField a bit more fuzzable (Evgeny Vereshchagin)
- Various cleanups to ISAKMP (#3798) (gpotter2)
- IKEv2: refactor the implementation (#3795) (Matthias St. Pierre)
- Remove python3_only and six from UTScapy (#3888) (Nils Weiss)
- Various DHCP fixes (#3912) (Evgeny Vereshchagin)
- Fix RawPcapReader usage with a Context Manager (Guillaume Valadon)
- DoIp: fix socket not handling IPv6 link-local address (#3840) (sa-isd)
- Add Optional Auth to BFD protocol (#3905) (ldaniel)
- Fix 3901 (#3902) (Nils Weiss)
- Make pack and unpack match in homeplugav.WriteModuleDataRequest (#3903) (Evgeny Vereshchagin)
- Skip the Ether part of hashret in the LLTD build/dissection test (#3904) (Evgeny Vereshchagin)
- Migrate to `pyproject.toml` (#3869) (gpotter2)
- Improvement of UDS_ServieEnumerator (#3879) (Nils Weiss)
- Use little-endian byte order to pack transaction lengths in PCOM (Evgeny Vereshchagin)
- Fix #3880: AutomotiveTestCaseExecutor on 32-bit machines (#3887) (Nils Weiss)
- arp_mitm: fix range iteration (gpotter2)
- Use network byte order explicitly to pack/unpack multi-byte integers in CoAP (Evgeny Vereshchagin)
- Fix UTF-16 on s390x (Evgeny Vereshchagin)
- setup: sanitize package version (#3862) (Robin Jarry)
- Slightly improve ARP poisoning utils (gpotter2)
- run_scapy: prefer the Python Launcher on Windows (Dr. Matthias St. Pierre)
- Add 802.11v BSS transition management request & response (#3827) (Alp Atakan İşbakan)
- Don’t distribute test directory into site-packages (#3838) (wim glenn)
- btle: Extend control PDU list with Bluetooth 5.3 PDUs (Rubin Gerritsen)
- Apply suggestions from code review (Matthias St. Pierre)
- Further cleanups (gpotter2)
- arch.linux: simplify proc file parsing (Matthias St. Pierre)
- Improvement of TesterPresentSenders (#3860) (Nils Weiss)
- Fix length calculation for GTPv2 header (#3833) (muelleme)
- Fix minor UT test (#3867) (gpotter2)
- Disable ping tests on OSX (gpotter2)
- Appveyor: allow scanner builds to fail (gpotter2)
- utils: fix warning about using variable before assignment (Matthias St. Pierre)
- Drop six library (second batch - contrib/) (Pierre Lalet)
- Fix tests that require git on non-git installs (gpotter2)
- fix typo in manpage (Carlos Henrique Lima Melara)
- Fix test without netbase (Evgeny Vereshchagin)
- Remove resource-heavy ISOTP test (gpotter2)
- Remove winpcap test (gpotter2)
- Fix proposition for #3831 - Options Template length not compliant with RFC 3954 (#3832) (Nicolas Bloyet)
- Cleanup of automotive scanner debug output (#3836) (Nils Weiss)
- Refactoring of stop_event in automotive scanners (Nils Weiss)
- Drop six library (first batch) (Pierre Lalet)
- GitHub Actions - remove Python 2.7 tests (Guillaume Valadon)
- AppVeyor - remove Python 2.7 tests (Guillaume Valadon)
- fix GTPDeletePDPContextResponse (vladimir1marchenko)

* Sat Jan 27 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jun 15 2023 Python Maint <python-maint@redhat.com> - 2.5.0-3
- Rebuilt for Python 3.12

* Sat Jan 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Jan 02 2023 Jonathan Wright <jonathan@almalinux.org> - 2.5.0-1
- Update to 2.5.0 rhbz#2156396

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 2.4.5-5
- Rebuilt for Python 3.11

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 2.4.5-2
- Rebuilt for Python 3.10

* Tue Apr 20 2021 Michal Ambroz <rebus _AT seznam.cz> - 2.4.5-1
- bump to 2.4.5 release

* Fri Mar 12 2021 Michal Ambroz <rebus _AT seznam.cz> - 2.4.4-1
- bump to 2.4.4 release

* Thu Mar 11 2021 W. Michael Petullo <mike@flyn.org> - 2.4.3-8
- Patch to fix loading libc.a; see https://bugs.python.org/issue42580

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 2.4.3-5
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Nov 08 2019 Michal Ambroz <rebus _AT seznam.cz> - 2.4.3-3
- remove colliding manpage from python2 package
- add license files
- add doc subpackage
- remove shebangs

* Sun Oct 06 2019 Michal Ambroz <rebus _AT seznam.cz> - 2.4.3-2
- change to recommended python build dependencies for EPEL7 - thanks Miro Hroncok

* Thu Sep 26 2019 Michal Ambroz <rebus _AT seznam.cz> - 2.4.3-1
- bump to 2.4.3 release
- change the python2 to conditional build to be able to keep one spec for all
- add Recommends for dependencies, except for EPEL7

* Fri Sep 20 2019 Miro Hrončok <mhroncok@redhat.com> - 2.4.0-8
- Subpackage python2-scapy has been removed
  See https://fedoraproject.org/wiki/Changes/Mass_Python_2_Package_Removal

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 2.4.0-7
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 2.4.0-3
- Rebuilt for Python 3.7

* Mon Apr 30 2018 Michal Ambroz <rebus _AT seznam.cz> - 2.4.0-2
- disable the test for now - there is too many failing (network) tests

* Mon Apr 30 2018 Michal Ambroz <rebus _AT seznam.cz> - 2.4.0-1
- bump to 2.4.0 release

* Fri Mar 9 2018 Michal Ambroz <rebus _AT seznam.cz> - 2.4.0-0.rc5.1
- bump to upstream 2.4.0 release candidate 5
- enable separate python3 and python2 build

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 31 2018 Iryna Shcherbina <ishcherb@redhat.com> - 2.3.3-3
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue May 23 2017 Michal Ambroz <rebus _AT seznam.cz> - 2.3.3-1
- bump to upstream 2.3.3

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Dec 26 2015 Sven Lankes <athmane@fedoraproject.org> - 2.3.1-1
- update to latest upstream release (2.3.1)
- Update to 2.3.1
- Remove upstreamed patch
- Some spec fixes
- Thanks to Athmane Madjoudj for the patch

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Oct 02 2014 Lubomir Rintel <lkundrak@v3.sk> - 2.2.0-5
- Fix psdump()/pdfdump()

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Jul 22 2012 Sven Lankes <sven@lank.es> - 2.2.0-1
- Update to Scapy 2.2.0
- Fixes rhbz #788659 - thanks to Thiébaud Weksteen

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0.10-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0.10-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0.10-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 2.0.0.10-4
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 22 2008 Devan Goodwin <dgoodwin@dangerouslyinc.com> 2.0.0.10-1
- Update to Scapy 2.0.0.10.

* Sun Dec 07 2008 Devan Goodwin <dgoodwin@dangerouslyinc.com> 2.0.0.9-2
- Update for Scapy 2.0.0.9.

* Tue Jan 22 2008 Devan Goodwin <dgoodwin@dangerouslyinc.com> 1.1.1-4
- Switch to using rm macro.

* Mon Jan 21 2008 Devan Goodwin <dgoodwin@dangerouslyinc.com> 1.1.1-2
- Spec file cleanup.

* Fri Jan 18 2008 Devan Goodwin <dgoodwin@dangerouslyinc.com> 1.1.1-1
- Initial packaging for Fedora.

